@@ -520,22 +520,22 @@ def run_solvents_barrage(stream, # Stream from which you wish to extract the sol
     #     fig = ax.get_figure()
     #     fig.savefig(file_to_save+'___'+str(final_results_df.columns[i])+'.png', bbox_inches='tight')
     
-    
     final_results_df.sort_values(by=final_results_df.columns[0], inplace=True)
-    ax1 = final_results_df.plot.barh( y=final_results_df.columns[0:3], figsize=(40,30), fontsize=52., ylabel=final_results_df.columns[i])
-    # ax.xlabel('xlabel', fontsize=18)
-    plt.xlabel('Partition coefficients at ' + str(T-273.15) + ' deg Celsius [(mol/mol)/(mol/mol)]', fontsize=52)
-    plt.legend(loc='lower right', prop={'size': 52})
-    fig1 = ax1.get_figure()
-    fig1.savefig(file_to_save+'___'+ 'Ks-solute-solvent-water'+'.png', bbox_inches='tight')
+    if plot_Ks:
+        ax1 = final_results_df.plot.barh( y=final_results_df.columns[0:3], figsize=(40,30), fontsize=52., ylabel=final_results_df.columns[i])
+        # ax.xlabel('xlabel', fontsize=18)
+        plt.xlabel('Partition coefficients at ' + str(T-273.15) + ' deg Celsius [(mol/mol)/(mol/mol)]', fontsize=52)
+        plt.legend(loc='lower right', prop={'size': 52})
+        fig1 = ax1.get_figure()
+        fig1.savefig(file_to_save+'___'+ 'Ks-solute-solvent-water'+'.png', bbox_inches='tight')
     
     
-    ax2 = final_results_df.plot.barh( y=final_results_df.columns[3:5], figsize=(40,30), fontsize=52., ylabel=final_results_df.columns[i])
-    # ax.xlabel('xlabel', fontsize=18)
-    plt.xlabel('Partition coefficients at ' + str(T-273.15) + ' deg Celsius [(mol/mol)/(mol/mol)]', fontsize=52)
-    plt.legend(loc='lower right', prop={'size': 52})
-    fig2 = ax2.get_figure()
-    fig2.savefig(file_to_save+'___'+ 'Ks-impurities-solvent'+'.png', bbox_inches='tight')
+        ax2 = final_results_df.plot.barh( y=final_results_df.columns[3:5], figsize=(40,30), fontsize=52., ylabel=final_results_df.columns[i])
+        # ax.xlabel('xlabel', fontsize=18)
+        plt.xlabel('Partition coefficients at ' + str(T-273.15) + ' deg Celsius [(mol/mol)/(mol/mol)]', fontsize=52)
+        plt.legend(loc='lower right', prop={'size': 52})
+        fig2 = ax2.get_figure()
+        fig2.savefig(file_to_save+'___'+ 'Ks-impurities-solvent'+'.png', bbox_inches='tight')
     
     return final_results_df
 
@@ -1053,7 +1053,8 @@ def run_solvents_barrage_v2(stream, # Stream from which you wish to extract the
     plt.xlabel('Partition coefficients at ' + str(T-273.15) + ' deg Celsius [(mol/mol)/(mol/mol)]', fontsize=52)
     plt.legend(loc='lower right', prop={'size': 52})
     fig1 = ax1.get_figure()
-    fig1.savefig(file_to_save+'___'+ 'Ks-solute-solvent-water'+'.png', bbox_inches='tight')
+    if save_K_plots:
+        fig1.savefig(file_to_save+'___'+ 'Ks-solute-solvent-water'+'.png', bbox_inches='tight')
     
     
     ax2 = final_results_df.plot.barh( y=final_results_df.columns[3:5], figsize=(40,30), fontsize=52., ylabel=final_results_df.columns[len(final_results_df.columns.values)-1])
@@ -1061,7 +1062,8 @@ def run_solvents_barrage_v2(stream, # Stream from which you wish to extract the
     plt.xlabel('Partition coefficients at ' + str(T-273.15) + ' deg Celsius [(mol/mol)/(mol/mol)]', fontsize=52)
     plt.legend(loc='lower right', prop={'size': 52})
     fig2 = ax2.get_figure()
-    fig2.savefig(file_to_save+'___'+ 'Ks-impurities-solvent'+'.png', bbox_inches='tight')
+    if save_K_plots:
+        fig2.savefig(file_to_save+'___'+ 'Ks-impurities-solvent'+'.png', bbox_inches='tight')
     
     return final_results_df
 
